@@ -250,9 +250,21 @@ func RedactedURL(s string) (string, error) {
 	return u.Redacted(), nil
 }
 
+// version of the CLI set by cmdapi.
+var version = "development"
+
+// SetVersion allow cmdapi to set the version
+// of the CLI provided at build time.
+func SetVersion(v, flavor string) {
+	version = v
+	if flavor != "" {
+		version += "-" + flavor
+	}
+}
+
 // SetHeader sets header fields for cloud requests.
 func SetHeader(req *http.Request, token string) {
 	req.Header.Set("Authorization", "Bearer "+token)
-	req.Header.Set("User-Agent", "atlas-cli")
+	req.Header.Set("User-Agent", fmt.Sprintf("Atlas/%s", version))
 	req.Header.Set("Content-Type", "application/json")
 }
