@@ -22,6 +22,7 @@ func TestClient_Dir(t *testing.T) {
 	require.NoError(t, dir.WriteFile("1.sql", []byte("create table foo (id int)")))
 	ad, err := migrate.ArchiveDir(&dir)
 	require.NoError(t, err)
+	SetVersion("v0.13.0", "")
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		var input struct {
 			Variables struct {
@@ -33,7 +34,7 @@ func TestClient_Dir(t *testing.T) {
 		require.Equal(t, "foo", input.Variables.DirInput.Name)
 		require.Equal(t, "x", input.Variables.DirInput.Tag)
 		require.Equal(t, "Bearer atlas", r.Header.Get("Authorization"))
-		require.Equal(t, "atlas-cli", r.Header.Get("User-Agent"))
+		require.Equal(t, "Atlas/v0.13.0", r.Header.Get("User-Agent"))
 		fmt.Fprintf(w, `{"data":{"dir":{"content":%q}}}`, base64.StdEncoding.EncodeToString(ad))
 	}))
 	client := New(srv.URL, "atlas")
