@@ -1903,11 +1903,9 @@ table "table" {
   }
   check {
     expr     = "price1 <> price2"
-    enforced = true
   }
   check {
     expr     = "price2 <> price1"
-    enforced = false
   }
   comment        = "table comment"
 }
