@@ -11,6 +11,7 @@ import (
 	"path/filepath"
 	"reflect"
 
+	"ariga.io/atlas/cmd/atlas/internal/cloudapi"
 	"ariga.io/atlas/cmd/atlas/internal/cmdext"
 	cmdmigrate "ariga.io/atlas/cmd/atlas/internal/migrate"
 	"ariga.io/atlas/schemahcl"
@@ -447,6 +448,7 @@ func parseConfig(path, env string, opts ...LoadOption) (*Project, error) {
 }
 
 func init() {
+	cloudapi.SetVersion(version, flavor)
 	schemahcl.Register(blockEnv, &Env{})
 }
 
