@@ -11,6 +11,7 @@ import (
 	"testing"
 
 	"ariga.io/atlas/cmd/atlas/internal/cmdext"
+	cmdmigrate "ariga.io/atlas/cmd/atlas/internal/migrate"
 	"ariga.io/atlas/schemahcl"
 	"ariga.io/atlas/sql/schema"
 
@@ -20,6 +21,7 @@ import (
 
 func TestEnvByName(t *testing.T) {
 	d := t.TempDir()
+	require.NoError(t, os.WriteFile(filepath.Join(d, "local.txt"), []byte("text"), 0600))
 	h := `
 variable "name" {
   type = string
@@ -29,6 +31,7 @@ variable "name" {
 locals {
   envName = atlas.env
   emptyEnv = getenv("NOT_SET")
+  opened = file("local.txt")
 }
 
 lint {
@@ -110,7 +113,7 @@ env "multi" {
 			Schemas: []string{"hello", "world"},
 			Migration: &Migration{
 				Dir:             "file://migrations",
-				Format:          formatAtlas,
+				Format:          cmdmigrate.FormatAtlas,
 				LockTimeout:     "1s",
 				RevisionsSchema: "revisions",
 			},
