@@ -293,7 +293,10 @@ func TestPostgres_Enums(t *testing.T) {
 		})
 
 		// Create table with an enum column.
-		err := t.drv.ApplyChanges(ctx, []schema.Change{&schema.AddTable{T: usersT}})
+		err := t.drv.ApplyChanges(ctx, []schema.Change{
+			&schema.AddObject{O: &schema.EnumType{T: "state", Values: []string{"on", "off"}, Schema: usersT.Schema}},
+			&schema.AddTable{T: usersT},
+		})
 		require.NoError(t, err, "create a new table with an enum column")
 		t.dropTables(usersT.Name)
 		ensureNoChange(t, usersT)
@@ -305,27 +308,12 @@ func TestPostgres_Enums(t *testing.T) {
 		)
 		changes := t.diff(t.loadUsers(), usersT)
 		require.Len(t, changes, 1)
-		err = t.drv.ApplyChanges(ctx, []schema.Change{&schema.ModifyTable{T: usersT, Changes: changes}})
+		err = t.drv.ApplyChanges(ctx, []schema.Change{
+			&schema.AddObject{O: &schema.EnumType{T: "day", Values: []string{"sunday", "monday"}, Schema: usersT.Schema}},
+			&schema.ModifyTable{T: usersT, Changes: changes},
+		})
 		require.NoError(t, err, "add a new enum column to existing table")
 		ensureNoChange(t, usersT)
-
-		// Add a new value to an existing enum.
-		e := usersT.Columns[1].Type.Type.(*schema.EnumType)
-		e.Values = append(e.Values, "tuesday")
-		changes = t.diff(t.loadUsers(), usersT)
-		require.Len(t, changes, 1)
-		err = t.drv.ApplyChanges(ctx, []schema.Change{&schema.ModifyTable{T: usersT, Changes: changes}})
-		require.NoError(t, err, "append a value to existing enum")
-		ensureNoChange(t, usersT)
-
-		// Add multiple new values to an existing enum.
-		e = usersT.Columns[1].Type.Type.(*schema.EnumType)
-		e.Values = append(e.Values, "wednesday", "thursday", "friday", "saturday")
-		changes = t.diff(t.loadUsers(), usersT)
-		require.Len(t, changes, 1)
-		err = t.drv.ApplyChanges(ctx, []schema.Change{&schema.ModifyTable{T: usersT, Changes: changes}})
-		require.NoError(t, err, "append multiple values to existing enum")
-		ensureNoChange(t, usersT)
 	})
 }
 
@@ -535,6 +523,7 @@ func TestPostgres_HCL_Realm(t *testing.T) {
 		require.NoError(t, err)
 		wa := string(hcl) + `
 schema "second" {
+  comment = "second schema"
 }
 `
 		t.applyRealmHcl(wa)
@@ -542,8 +531,10 @@ schema "second" {
 		require.NoError(t, err)
 		_, ok := realm.Schema("public")
 		require.True(t, ok)
-		_, ok = realm.Schema("second")
+		s2, ok := realm.Schema("second")
 		require.True(t, ok)
+		require.Len(t, s2.Attrs, 1)
+		require.Equal(t, "second schema", s2.Attrs[0].(*schema.Comment).Text)
 	})
 }
 
@@ -778,9 +769,96 @@ func TestPostgres_CLI_MultiSchema(t *testing.T) {
 	})
 }
 
+func TestPostgres_NormalizeRealm(t *testing.T) {
+	bin := cliPath(t)
+	pgRun(t, func(t *pgTest) {
+		dir := t.TempDir()
+		_, err := t.db.Exec("CREATE DATABASE normalized_realm")
+		require.NoError(t, err)
+		defer t.db.Exec("DROP DATABASE IF EXISTS normalized_realm")
+		hcl := `
+schema "public" {}
+enum "status" {
+  schema = schema.public
+  values = ["active", "inactive"]
+}
+
+table "users" {
+  schema = schema.public
+  column "id" { type = serial }
+  column "e"  { type = enum.status }
+  column "ae" { type = sql("status[]") }
+}
+
+schema "other" {}
+table "posts" {
+  schema = schema.other
+  column "id" { type = integer }
+}
+
+table "with_default" {
+  schema = schema.other
+  column "name" {
+    type = varchar
+	default = sql("lower('Hello')")
+  }
+}
+`
+		err = os.WriteFile(filepath.Join(dir, "schema.hcl"), []byte(hcl), 0600)
+		require.NoError(t, err)
+		out, err := exec.Command(
+			bin, "schema", "inspect",
+			"--url", fmt.Sprintf("file://%s", filepath.Join(dir, "schema.hcl")),
+			"--dev-url", fmt.Sprintf("postgres://postgres:pass@localhost:%d/normalized_realm?sslmode=disable", t.port),
+		).CombinedOutput()
+		require.NoError(t, err)
+		require.Equal(t, `table "posts" {
+  schema = schema.other
+  column "id" {
+    null = false
+    type = integer
+  }
+}
+table "with_default" {
+  schema = schema.other
+  column "name" {
+    null    = false
+    type    = character_varying
+    default = sql("lower('Hello'::text)")
+  }
+}
+table "users" {
+  schema = schema.public
+  column "id" {
+    null = false
+    type = serial
+  }
+  column "e" {
+    null = false
+    type = enum.status
+  }
+  column "ae" {
+    null = false
+    type = sql("status[]")
+  }
+}
+enum "status" {
+  schema = schema.public
+  values = ["active", "inactive"]
+}
+schema "other" {
+}
+schema "public" {
+  comment = "standard public schema"
+}
+`, string(out))
+		err = t.drv.(migrate.CleanChecker).CheckClean(context.Background(), nil)
+		require.NoError(t, err)
+	})
+}
+
 func TestPostgres_MigrateDiffRealm(t *testing.T) {
-	bin, err := buildCmd(t)
-	require.NoError(t, err)
+	bin := cliPath(t)
 	pgRun(t, func(t *pgTest) {
 		dir := t.TempDir()
 		_, err := t.db.Exec("CREATE DATABASE migrate_diff")
@@ -851,11 +929,10 @@ CREATE TABLE "other"."users" ("id" integer NOT NULL);
 }
 
 func TestPostgres_SchemaDiff(t *testing.T) {
-	bin, err := buildCmd(t)
-	require.NoError(t, err)
+	bin := cliPath(t)
 	pgRun(t, func(t *pgTest) {
 		dir := t.TempDir()
-		_, err = t.db.Exec("CREATE DATABASE test1")
+		_, err := t.db.Exec("CREATE DATABASE test1")
 		require.NoError(t, err)
 		t.Cleanup(func() {
 			_, err := t.db.Exec("DROP DATABASE IF EXISTS test1")
@@ -882,7 +959,9 @@ func TestPostgres_SchemaDiff(t *testing.T) {
 
 		// Create schemas on test2 database.
 		hcl := `
-schema "public" {}
+schema "public" {
+  comment = "standard public schema"
+}
 table "users" {
 	schema = schema.public
 	column "id" { type = integer }
@@ -910,11 +989,12 @@ CREATE SCHEMA "other";
 CREATE TABLE "public"."users" ("id" integer NOT NULL);
 -- Create "posts" table
 CREATE TABLE "other"."posts" ("id" integer NOT NULL);`, diff("test1?sslmode=disable", "test2?sslmode=disable"))
-		// diff schemas
-		require.Equal(t, `-- Drop "posts" table
-DROP TABLE "posts";
--- Create "users" table
-CREATE TABLE "users" ("id" integer NOT NULL);`, diff("test2?sslmode=disable&search_path=other", "test2?sslmode=disable&search_path=public"))
+
+		// Diffing schema should both tables and comments (from 'public' to 'other').
+		require.Equal(t, `-- Create "users" table
+CREATE TABLE "users" ("id" integer NOT NULL);
+-- Drop "posts" table
+DROP TABLE "posts";`, diff("test2?sslmode=disable&search_path=other", "test2?sslmode=disable&search_path=public"))
 		// diff between schema and database
 		out, err = exec.Command(
 			bin, "schema", "diff",
@@ -926,6 +1006,50 @@ CREATE TABLE "users" ("id" integer NOT NULL);`, diff("test2?sslmode=disable&sear
 	})
 }
 
+func TestPostgres_MigrateDiffEnt(t *testing.T) {
+	bin := cliPath(t)
+	pgRun(t, func(t *pgTest) {
+		dir := t.TempDir()
+		_, err := t.db.Exec("CREATE SCHEMA IF NOT EXISTS entdev")
+		require.NoError(t, err)
+		t.dropSchemas("entdev")
+
+		entdir, migratedir := filepath.Join(dir, "entschema"), filepath.Join(dir, "migrations")
+		require.NoError(t, os.Mkdir(entdir, 0755))
+		err = os.WriteFile(filepath.Join(entdir, "user.go"), []byte(`
+package schema
+
+import "entgo.io/ent"
+
+type User struct { ent.Schema }
+`), 0600)
+		require.NoError(t, err)
+		for _, ts := range [][]string{{"init", "entschema"}, {"tidy"}} {
+			cmd := exec.Command("go", append([]string{"mod"}, ts...)...)
+			cmd.Dir = dir
+			require.NoError(t, cmd.Run())
+		}
+		cmd := exec.Command(
+			bin, "migrate", "diff",
+			"--dev-url", fmt.Sprintf("postgres://postgres:pass@localhost:%d/test?search_path=entdev&sslmode=disable", t.port),
+			"--to", "ent://"+entdir,
+			"--dir", "file://"+migratedir,
+		)
+		cmd.Dir = dir
+		require.NoError(t, cmd.Run())
+		local, err := migrate.NewLocalDir(migratedir)
+		require.NoError(t, err)
+		files, err := local.Files()
+		require.NoError(t, err)
+		require.Equal(t, 1, len(files))
+		stmts, err := files[0].Stmts()
+		require.NoError(t, err)
+		require.Equal(t, []string{
+			`CREATE TABLE "users" ("id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY, PRIMARY KEY ("id"));`,
+		}, stmts)
+	})
+}
+
 func TestPostgres_DefaultsHCL(t *testing.T) {
 	n := "atlas_defaults"
 	pgRun(t, func(t *pgTest) {
@@ -1370,6 +1494,7 @@ func (t *pgTest) valueByVersion(values map[string]string, defaults string) strin
 func (t *pgTest) loadRealm() *schema.Realm {
 	r, err := t.drv.InspectRealm(context.Background(), &schema.InspectRealmOption{
 		Schemas: []string{"public"},
+		Mode:    ^schema.InspectViews,
 	})
 	require.NoError(t, err)
 	return r
@@ -1455,6 +1580,9 @@ func (t *pgTest) realm() *schema.Realm {
 		Schemas: []*schema.Schema{
 			{
 				Name: "public",
+				Attrs: []schema.Attr{
+					&schema.Comment{Text: "standard public schema"},
+				},
 			},
 		},
 		Attrs: []schema.Attr{
