@@ -84,7 +84,7 @@ func newLex(input string) (*lex, error) {
 		}
 		parts := strings.SplitN(input, "\n", 2)
 		if len(parts) == 1 {
-			return nil, fmt.Errorf("no input found after delimiter %q", d)
+			return nil, l.error(l.pos, "no input found after delimiter %q", d)
 		}
 		l.input = parts[1]
 	}
@@ -96,8 +96,8 @@ var reDollarQuote = regexp.MustCompile(`^\$([A-Za-zÈ-ÿ_][\wÈ-ÿ]*)*\$`)
 
 func (l *lex) stmt() (*Stmt, error) {
 	var (
-		depth int
-		text  string
+		depth, openingPos int
+		text              string
 	)
 	l.skipSpaces()
 Scan:
@@ -106,7 +106,7 @@ Scan:
 		case r == eos:
 			switch {
 			case depth > 0:
-				return nil, errors.New("unclosed parentheses")
+				return nil, l.error(openingPos, "unclosed '('")
 			case l.pos > 0:
 				text = l.input
 				break Scan
@@ -114,10 +114,13 @@ Scan:
 				return nil, io.EOF
 			}
 		case r == '(':
+			if depth == 0 {
+				openingPos = l.pos
+			}
 			depth++
 		case r == ')':
 			if depth == 0 {
-				return nil, fmt.Errorf("unexpected ')' at position %d", l.pos)
+				return nil, l.error(l.pos, "unexpected ')'")
 			}
 			depth--
 		case r == '\'', r == '"', r == '`':
@@ -174,10 +177,11 @@ func (l *lex) addPos(p int) {
 }
 
 func (l *lex) skipQuote(quote rune) error {
+	pos := l.pos
 	for {
 		switch r := l.next(); {
 		case r == eos:
-			return fmt.Errorf("unclosed quote %q", quote)
+			return l.error(pos, "unclosed quote %q", quote)
 		case r == '\\':
 			l.next()
 		case r == quote:
@@ -189,7 +193,7 @@ func (l *lex) skipQuote(quote rune) error {
 func (l *lex) skipDollarQuote() error {
 	m := reDollarQuote.FindString(l.input[l.pos-1:])
 	if m == "" {
-		return fmt.Errorf("unexpected dollar quote at position %d", l.pos)
+		return l.error(l.pos, "unexpected dollar quote")
 	}
 	l.addPos(len(m) - 1)
 	for {
@@ -197,7 +201,7 @@ func (l *lex) skipDollarQuote() error {
 		case r == eos:
 			// Fail only if a delimiter was not set.
 			if l.delim == "" {
-				return errors.New("unclosed dollar-quoted string")
+				return l.error(l.pos, "unclosed dollar-quoted string")
 			}
 			return nil
 		case r == '$' && strings.HasPrefix(l.input[l.pos-1:], m):
@@ -281,3 +285,18 @@ func (l *lex) setDelim(d string) error {
 	l.delim = strings.NewReplacer(`\n`, "\n", `\r`, "\r", `\t`, "\t").Replace(d)
 	return nil
 }
+
+func (l *lex) error(pos int, format string, args ...any) error {
+	format = "%d:%d: " + format
+	var (
+		s    = l.input[:pos]
+		col  = strings.LastIndex(s, "\n")
+		line = 1 + strings.Count(s, "\n")
+	)
+	if line == 1 {
+		col = pos
+	} else {
+		col = pos - col - 1
+	}
+	return fmt.Errorf(format, append([]any{line, col}, args...)...)
+}
